# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'GetGroupResult',
    'AwaitableGetGroupResult',
    'get_group',
    'get_group_output',
]

@pulumi.output_type
class GetGroupResult:
    """
    A collection of values returned by getGroup.
    """
    def __init__(__self__, id=None, name=None, qos_rate_max_down=None, qos_rate_max_up=None, site=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if qos_rate_max_down and not isinstance(qos_rate_max_down, int):
            raise TypeError("Expected argument 'qos_rate_max_down' to be a int")
        pulumi.set(__self__, "qos_rate_max_down", qos_rate_max_down)
        if qos_rate_max_up and not isinstance(qos_rate_max_up, int):
            raise TypeError("Expected argument 'qos_rate_max_up' to be a int")
        pulumi.set(__self__, "qos_rate_max_up", qos_rate_max_up)
        if site and not isinstance(site, str):
            raise TypeError("Expected argument 'site' to be a str")
        pulumi.set(__self__, "site", site)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of this AP group.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> Optional[str]:
        """
        The name of the user group to look up. Defaults to `Default`.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="qosRateMaxDown")
    def qos_rate_max_down(self) -> int:
        return pulumi.get(self, "qos_rate_max_down")

    @property
    @pulumi.getter(name="qosRateMaxUp")
    def qos_rate_max_up(self) -> int:
        return pulumi.get(self, "qos_rate_max_up")

    @property
    @pulumi.getter
    def site(self) -> str:
        """
        The name of the site the user group is associated with.
        """
        return pulumi.get(self, "site")


class AwaitableGetGroupResult(GetGroupResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetGroupResult(
            id=self.id,
            name=self.name,
            qos_rate_max_down=self.qos_rate_max_down,
            qos_rate_max_up=self.qos_rate_max_up,
            site=self.site)


def get_group(name: Optional[str] = None,
              site: Optional[str] = None,
              opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetGroupResult:
    """
    `iam.Group` data source can be used to retrieve the ID for a user group by name.


    :param str name: The name of the user group to look up. Defaults to `Default`.
    :param str site: The name of the site the user group is associated with.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['site'] = site
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('unifi:iam/getGroup:getGroup', __args__, opts=opts, typ=GetGroupResult).value

    return AwaitableGetGroupResult(
        id=__ret__.id,
        name=__ret__.name,
        qos_rate_max_down=__ret__.qos_rate_max_down,
        qos_rate_max_up=__ret__.qos_rate_max_up,
        site=__ret__.site)


@_utilities.lift_output_func(get_group)
def get_group_output(name: Optional[pulumi.Input[Optional[str]]] = None,
                     site: Optional[pulumi.Input[Optional[str]]] = None,
                     opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetGroupResult]:
    """
    `iam.Group` data source can be used to retrieve the ID for a user group by name.


    :param str name: The name of the user group to look up. Defaults to `Default`.
    :param str site: The name of the site the user group is associated with.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = [
    'GetNetworkResult',
    'AwaitableGetNetworkResult',
    'get_network',
    'get_network_output',
]

@pulumi.output_type
class GetNetworkResult:
    """
    A collection of values returned by getNetwork.
    """
    def __init__(__self__, dhcp_dns=None, dhcp_enabled=None, dhcp_lease=None, dhcp_start=None, dhcp_stop=None, dhcpd_boot_enabled=None, dhcpd_boot_filename=None, dhcpd_boot_server=None, domain_name=None, id=None, igmp_snooping=None, ipv6_interface_type=None, ipv6_pd_interface=None, ipv6_pd_prefixid=None, ipv6_ra_enable=None, ipv6_static_subnet=None, name=None, network_group=None, purpose=None, site=None, subnet=None, vlan_id=None, wan_dns=None, wan_egress_qos=None, wan_gateway=None, wan_ip=None, wan_netmask=None, wan_networkgroup=None, wan_type=None, wan_username=None, x_wan_password=None):
        if dhcp_dns and not isinstance(dhcp_dns, list):
            raise TypeError("Expected argument 'dhcp_dns' to be a list")
        pulumi.set(__self__, "dhcp_dns", dhcp_dns)
        if dhcp_enabled and not isinstance(dhcp_enabled, bool):
            raise TypeError("Expected argument 'dhcp_enabled' to be a bool")
        pulumi.set(__self__, "dhcp_enabled", dhcp_enabled)
        if dhcp_lease and not isinstance(dhcp_lease, int):
            raise TypeError("Expected argument 'dhcp_lease' to be a int")
        pulumi.set(__self__, "dhcp_lease", dhcp_lease)
        if dhcp_start and not isinstance(dhcp_start, str):
            raise TypeError("Expected argument 'dhcp_start' to be a str")
        pulumi.set(__self__, "dhcp_start", dhcp_start)
        if dhcp_stop and not isinstance(dhcp_stop, str):
            raise TypeError("Expected argument 'dhcp_stop' to be a str")
        pulumi.set(__self__, "dhcp_stop", dhcp_stop)
        if dhcpd_boot_enabled and not isinstance(dhcpd_boot_enabled, bool):
            raise TypeError("Expected argument 'dhcpd_boot_enabled' to be a bool")
        pulumi.set(__self__, "dhcpd_boot_enabled", dhcpd_boot_enabled)
        if dhcpd_boot_filename and not isinstance(dhcpd_boot_filename, str):
            raise TypeError("Expected argument 'dhcpd_boot_filename' to be a str")
        pulumi.set(__self__, "dhcpd_boot_filename", dhcpd_boot_filename)
        if dhcpd_boot_server and not isinstance(dhcpd_boot_server, str):
            raise TypeError("Expected argument 'dhcpd_boot_server' to be a str")
        pulumi.set(__self__, "dhcpd_boot_server", dhcpd_boot_server)
        if domain_name and not isinstance(domain_name, str):
            raise TypeError("Expected argument 'domain_name' to be a str")
        pulumi.set(__self__, "domain_name", domain_name)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if igmp_snooping and not isinstance(igmp_snooping, bool):
            raise TypeError("Expected argument 'igmp_snooping' to be a bool")
        pulumi.set(__self__, "igmp_snooping", igmp_snooping)
        if ipv6_interface_type and not isinstance(ipv6_interface_type, str):
            raise TypeError("Expected argument 'ipv6_interface_type' to be a str")
        pulumi.set(__self__, "ipv6_interface_type", ipv6_interface_type)
        if ipv6_pd_interface and not isinstance(ipv6_pd_interface, str):
            raise TypeError("Expected argument 'ipv6_pd_interface' to be a str")
        pulumi.set(__self__, "ipv6_pd_interface", ipv6_pd_interface)
        if ipv6_pd_prefixid and not isinstance(ipv6_pd_prefixid, str):
            raise TypeError("Expected argument 'ipv6_pd_prefixid' to be a str")
        pulumi.set(__self__, "ipv6_pd_prefixid", ipv6_pd_prefixid)
        if ipv6_ra_enable and not isinstance(ipv6_ra_enable, bool):
            raise TypeError("Expected argument 'ipv6_ra_enable' to be a bool")
        pulumi.set(__self__, "ipv6_ra_enable", ipv6_ra_enable)
        if ipv6_static_subnet and not isinstance(ipv6_static_subnet, str):
            raise TypeError("Expected argument 'ipv6_static_subnet' to be a str")
        pulumi.set(__self__, "ipv6_static_subnet", ipv6_static_subnet)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if network_group and not isinstance(network_group, str):
            raise TypeError("Expected argument 'network_group' to be a str")
        pulumi.set(__self__, "network_group", network_group)
        if purpose and not isinstance(purpose, str):
            raise TypeError("Expected argument 'purpose' to be a str")
        pulumi.set(__self__, "purpose", purpose)
        if site and not isinstance(site, str):
            raise TypeError("Expected argument 'site' to be a str")
        pulumi.set(__self__, "site", site)
        if subnet and not isinstance(subnet, str):
            raise TypeError("Expected argument 'subnet' to be a str")
        pulumi.set(__self__, "subnet", subnet)
        if vlan_id and not isinstance(vlan_id, int):
            raise TypeError("Expected argument 'vlan_id' to be a int")
        pulumi.set(__self__, "vlan_id", vlan_id)
        if wan_dns and not isinstance(wan_dns, list):
            raise TypeError("Expected argument 'wan_dns' to be a list")
        pulumi.set(__self__, "wan_dns", wan_dns)
        if wan_egress_qos and not isinstance(wan_egress_qos, int):
            raise TypeError("Expected argument 'wan_egress_qos' to be a int")
        pulumi.set(__self__, "wan_egress_qos", wan_egress_qos)
        if wan_gateway and not isinstance(wan_gateway, str):
            raise TypeError("Expected argument 'wan_gateway' to be a str")
        pulumi.set(__self__, "wan_gateway", wan_gateway)
        if wan_ip and not isinstance(wan_ip, str):
            raise TypeError("Expected argument 'wan_ip' to be a str")
        pulumi.set(__self__, "wan_ip", wan_ip)
        if wan_netmask and not isinstance(wan_netmask, str):
            raise TypeError("Expected argument 'wan_netmask' to be a str")
        pulumi.set(__self__, "wan_netmask", wan_netmask)
        if wan_networkgroup and not isinstance(wan_networkgroup, str):
            raise TypeError("Expected argument 'wan_networkgroup' to be a str")
        pulumi.set(__self__, "wan_networkgroup", wan_networkgroup)
        if wan_type and not isinstance(wan_type, str):
            raise TypeError("Expected argument 'wan_type' to be a str")
        pulumi.set(__self__, "wan_type", wan_type)
        if wan_username and not isinstance(wan_username, str):
            raise TypeError("Expected argument 'wan_username' to be a str")
        pulumi.set(__self__, "wan_username", wan_username)
        if x_wan_password and not isinstance(x_wan_password, str):
            raise TypeError("Expected argument 'x_wan_password' to be a str")
        pulumi.set(__self__, "x_wan_password", x_wan_password)

    @property
    @pulumi.getter(name="dhcpDns")
    def dhcp_dns(self) -> Sequence[str]:
        """
        IPv4 addresses for the DNS server to be returned from the DHCP server.
        """
        return pulumi.get(self, "dhcp_dns")

    @property
    @pulumi.getter(name="dhcpEnabled")
    def dhcp_enabled(self) -> bool:
        """
        whether DHCP is enabled or not on this network.
        """
        return pulumi.get(self, "dhcp_enabled")

    @property
    @pulumi.getter(name="dhcpLease")
    def dhcp_lease(self) -> int:
        """
        lease time for DHCP addresses.
        """
        return pulumi.get(self, "dhcp_lease")

    @property
    @pulumi.getter(name="dhcpStart")
    def dhcp_start(self) -> str:
        """
        The IPv4 address where the DHCP range of addresses starts.
        """
        return pulumi.get(self, "dhcp_start")

    @property
    @pulumi.getter(name="dhcpStop")
    def dhcp_stop(self) -> str:
        """
        The IPv4 address where the DHCP range of addresses stops.
        """
        return pulumi.get(self, "dhcp_stop")

    @property
    @pulumi.getter(name="dhcpdBootEnabled")
    def dhcpd_boot_enabled(self) -> bool:
        """
        Toggles on the DHCP boot options. will be set to true if you have dhcpd*boot*filename, and dhcpd*boot*server set.
        """
        return pulumi.get(self, "dhcpd_boot_enabled")

    @property
    @pulumi.getter(name="dhcpdBootFilename")
    def dhcpd_boot_filename(self) -> str:
        """
        the file to PXE boot from on the dhcpd*boot*server.
        """
        return pulumi.get(self, "dhcpd_boot_filename")

    @property
    @pulumi.getter(name="dhcpdBootServer")
    def dhcpd_boot_server(self) -> str:
        """
        IPv4 address of a TFTP server to network boot from.
        """
        return pulumi.get(self, "dhcpd_boot_server")

    @property
    @pulumi.getter(name="domainName")
    def domain_name(self) -> str:
        """
        The domain name of this network.
        """
        return pulumi.get(self, "domain_name")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the network.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="igmpSnooping")
    def igmp_snooping(self) -> bool:
        """
        Specifies whether IGMP snooping is enabled or not.
        """
        return pulumi.get(self, "igmp_snooping")

    @property
    @pulumi.getter(name="ipv6InterfaceType")
    def ipv6_interface_type(self) -> str:
        """
        Specifies which type of IPv6 connection to use.
        """
        return pulumi.get(self, "ipv6_interface_type")

    @property
    @pulumi.getter(name="ipv6PdInterface")
    def ipv6_pd_interface(self) -> str:
        """
        Specifies which WAN interface is used for IPv6 Prefix Delegation.
        """
        return pulumi.get(self, "ipv6_pd_interface")

    @property
    @pulumi.getter(name="ipv6PdPrefixid")
    def ipv6_pd_prefixid(self) -> str:
        """
        Specifies the IPv6 Prefix ID.
        """
        return pulumi.get(self, "ipv6_pd_prefixid")

    @property
    @pulumi.getter(name="ipv6RaEnable")
    def ipv6_ra_enable(self) -> bool:
        """
        Specifies whether to enable router advertisements or not.
        """
        return pulumi.get(self, "ipv6_ra_enable")

    @property
    @pulumi.getter(name="ipv6StaticSubnet")
    def ipv6_static_subnet(self) -> str:
        """
        Specifies the static IPv6 subnet (when ipv6*interface*type is 'static').
        """
        return pulumi.get(self, "ipv6_static_subnet")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        The name of the network.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="networkGroup")
    def network_group(self) -> str:
        """
        The group of the network.
        """
        return pulumi.get(self, "network_group")

    @property
    @pulumi.getter
    def purpose(self) -> str:
        """
        The purpose of the network. One of `corporate`, `guest`, `wan`, or `vlan-only`.
        """
        return pulumi.get(self, "purpose")

    @property
    @pulumi.getter
    def site(self) -> str:
        """
        The name of the site to associate the network with.
        """
        return pulumi.get(self, "site")

    @property
    @pulumi.getter
    def subnet(self) -> str:
        """
        The subnet of the network (CIDR address).
        """
        return pulumi.get(self, "subnet")

    @property
    @pulumi.getter(name="vlanId")
    def vlan_id(self) -> int:
        """
        The VLAN ID of the network.
        """
        return pulumi.get(self, "vlan_id")

    @property
    @pulumi.getter(name="wanDns")
    def wan_dns(self) -> Sequence[str]:
        """
        DNS servers IPs of the WAN.
        """
        return pulumi.get(self, "wan_dns")

    @property
    @pulumi.getter(name="wanEgressQos")
    def wan_egress_qos(self) -> int:
        """
        Specifies the WAN egress quality of service.
        """
        return pulumi.get(self, "wan_egress_qos")

    @property
    @pulumi.getter(name="wanGateway")
    def wan_gateway(self) -> str:
        """
        The IPv4 gateway of the WAN.
        """
        return pulumi.get(self, "wan_gateway")

    @property
    @pulumi.getter(name="wanIp")
    def wan_ip(self) -> str:
        """
        The IPv4 address of the WAN.
        """
        return pulumi.get(self, "wan_ip")

    @property
    @pulumi.getter(name="wanNetmask")
    def wan_netmask(self) -> str:
        """
        The IPv4 netmask of the WAN.
        """
        return pulumi.get(self, "wan_netmask")

    @property
    @pulumi.getter(name="wanNetworkgroup")
    def wan_networkgroup(self) -> str:
        """
        Specifies the WAN network group. One of either `WAN`, `WAN2` or `WAN_LTE_FAILOVER`.
        """
        return pulumi.get(self, "wan_networkgroup")

    @property
    @pulumi.getter(name="wanType")
    def wan_type(self) -> str:
        """
        Specifies the IPV4 WAN connection type. One of either `disabled`, `static`, `dhcp`, or `pppoe`.
        """
        return pulumi.get(self, "wan_type")

    @property
    @pulumi.getter(name="wanUsername")
    def wan_username(self) -> str:
        """
        Specifies the IPV4 WAN username.
        """
        return pulumi.get(self, "wan_username")

    @property
    @pulumi.getter(name="xWanPassword")
    def x_wan_password(self) -> str:
        """
        Specifies the IPV4 WAN password.
        """
        return pulumi.get(self, "x_wan_password")


class AwaitableGetNetworkResult(GetNetworkResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetNetworkResult(
            dhcp_dns=self.dhcp_dns,
            dhcp_enabled=self.dhcp_enabled,
            dhcp_lease=self.dhcp_lease,
            dhcp_start=self.dhcp_start,
            dhcp_stop=self.dhcp_stop,
            dhcpd_boot_enabled=self.dhcpd_boot_enabled,
            dhcpd_boot_filename=self.dhcpd_boot_filename,
            dhcpd_boot_server=self.dhcpd_boot_server,
            domain_name=self.domain_name,
            id=self.id,
            igmp_snooping=self.igmp_snooping,
            ipv6_interface_type=self.ipv6_interface_type,
            ipv6_pd_interface=self.ipv6_pd_interface,
            ipv6_pd_prefixid=self.ipv6_pd_prefixid,
            ipv6_ra_enable=self.ipv6_ra_enable,
            ipv6_static_subnet=self.ipv6_static_subnet,
            name=self.name,
            network_group=self.network_group,
            purpose=self.purpose,
            site=self.site,
            subnet=self.subnet,
            vlan_id=self.vlan_id,
            wan_dns=self.wan_dns,
            wan_egress_qos=self.wan_egress_qos,
            wan_gateway=self.wan_gateway,
            wan_ip=self.wan_ip,
            wan_netmask=self.wan_netmask,
            wan_networkgroup=self.wan_networkgroup,
            wan_type=self.wan_type,
            wan_username=self.wan_username,
            x_wan_password=self.x_wan_password)


def get_network(id: Optional[str] = None,
                name: Optional[str] = None,
                site: Optional[str] = None,
                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetNetworkResult:
    """
    `Network` data source can be used to retrieve settings for a network by name or ID.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_unifi as unifi

    lan_network = unifi.get_network(name="LAN")
    my_device = unifi.iam.get_user(mac="01:23:45:67:89:ab")
    my_network = unifi.get_network(id=my_device.network_id)
    ```


    :param str id: The ID of the network.
    :param str name: The name of the network.
    :param str site: The name of the site to associate the network with.
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['name'] = name
    __args__['site'] = site
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('unifi:index/getNetwork:getNetwork', __args__, opts=opts, typ=GetNetworkResult).value

    return AwaitableGetNetworkResult(
        dhcp_dns=__ret__.dhcp_dns,
        dhcp_enabled=__ret__.dhcp_enabled,
        dhcp_lease=__ret__.dhcp_lease,
        dhcp_start=__ret__.dhcp_start,
        dhcp_stop=__ret__.dhcp_stop,
        dhcpd_boot_enabled=__ret__.dhcpd_boot_enabled,
        dhcpd_boot_filename=__ret__.dhcpd_boot_filename,
        dhcpd_boot_server=__ret__.dhcpd_boot_server,
        domain_name=__ret__.domain_name,
        id=__ret__.id,
        igmp_snooping=__ret__.igmp_snooping,
        ipv6_interface_type=__ret__.ipv6_interface_type,
        ipv6_pd_interface=__ret__.ipv6_pd_interface,
        ipv6_pd_prefixid=__ret__.ipv6_pd_prefixid,
        ipv6_ra_enable=__ret__.ipv6_ra_enable,
        ipv6_static_subnet=__ret__.ipv6_static_subnet,
        name=__ret__.name,
        network_group=__ret__.network_group,
        purpose=__ret__.purpose,
        site=__ret__.site,
        subnet=__ret__.subnet,
        vlan_id=__ret__.vlan_id,
        wan_dns=__ret__.wan_dns,
        wan_egress_qos=__ret__.wan_egress_qos,
        wan_gateway=__ret__.wan_gateway,
        wan_ip=__ret__.wan_ip,
        wan_netmask=__ret__.wan_netmask,
        wan_networkgroup=__ret__.wan_networkgroup,
        wan_type=__ret__.wan_type,
        wan_username=__ret__.wan_username,
        x_wan_password=__ret__.x_wan_password)


@_utilities.lift_output_func(get_network)
def get_network_output(id: Optional[pulumi.Input[Optional[str]]] = None,
                       name: Optional[pulumi.Input[Optional[str]]] = None,
                       site: Optional[pulumi.Input[Optional[str]]] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetNetworkResult]:
    """
    `Network` data source can be used to retrieve settings for a network by name or ID.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_unifi as unifi

    lan_network = unifi.get_network(name="LAN")
    my_device = unifi.iam.get_user(mac="01:23:45:67:89:ab")
    my_network = unifi.get_network(id=my_device.network_id)
    ```


    :param str id: The ID of the network.
    :param str name: The name of the network.
    :param str site: The name of the site to associate the network with.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['RuleArgs', 'Rule']

@pulumi.input_type
class RuleArgs:
    def __init__(__self__, *,
                 action: pulumi.Input[str],
                 protocol: pulumi.Input[str],
                 rule_index: pulumi.Input[int],
                 ruleset: pulumi.Input[str],
                 dst_address: Optional[pulumi.Input[str]] = None,
                 dst_firewall_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 dst_network_id: Optional[pulumi.Input[str]] = None,
                 dst_network_type: Optional[pulumi.Input[str]] = None,
                 dst_port: Optional[pulumi.Input[str]] = None,
                 icmp_typename: Optional[pulumi.Input[str]] = None,
                 ip_sec: Optional[pulumi.Input[str]] = None,
                 logging: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 site: Optional[pulumi.Input[str]] = None,
                 src_address: Optional[pulumi.Input[str]] = None,
                 src_firewall_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 src_mac: Optional[pulumi.Input[str]] = None,
                 src_network_id: Optional[pulumi.Input[str]] = None,
                 src_network_type: Optional[pulumi.Input[str]] = None,
                 state_established: Optional[pulumi.Input[bool]] = None,
                 state_invalid: Optional[pulumi.Input[bool]] = None,
                 state_new: Optional[pulumi.Input[bool]] = None,
                 state_related: Optional[pulumi.Input[bool]] = None):
        """
        The set of arguments for constructing a Rule resource.
        :param pulumi.Input[str] action: The action of the firewall rule. Must be one of `drop`, `accept`, or `reject`.
        :param pulumi.Input[str] protocol: The protocol of the rule.
        :param pulumi.Input[int] rule_index: The index of the rule. Must be >= 2000 < 3000 or >= 4000 < 5000.
        :param pulumi.Input[str] ruleset: The ruleset for the rule. This is from the perspective of the security gateway. Must be one of `WAN_IN`, `WAN_OUT`, `WAN_LOCAL`, `LAN_IN`, `LAN_OUT`, `LAN_LOCAL`, `GUEST_IN`, `GUEST_OUT`, `GUEST_LOCAL`, `WANv6_IN`, `WANv6_OUT`, `WANv6_LOCAL`, `LANv6_IN`, `LANv6_OUT`, `LANv6_LOCAL`, `GUESTv6_IN`, `GUESTv6_OUT`, or `GUESTv6_LOCAL`.
        :param pulumi.Input[str] dst_address: The destination address of the firewall rule.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] dst_firewall_group_ids: The destination firewall group IDs of the firewall rule.
        :param pulumi.Input[str] dst_network_id: The destination network ID of the firewall rule.
        :param pulumi.Input[str] dst_network_type: The destination network type of the firewall rule. Can be one of `ADDRv4` or `NETv4`. Defaults to `NETv4`.
        :param pulumi.Input[str] dst_port: The destination port of the firewall rule.
        :param pulumi.Input[str] icmp_typename: ICMP type name.
        :param pulumi.Input[str] ip_sec: Specify whether the rule matches on IPsec packets. Can be one of `match-ipset` or `match-none`.
        :param pulumi.Input[bool] logging: Enable logging for the firewall rule.
        :param pulumi.Input[str] name: The name of the firewall rule.
        :param pulumi.Input[str] site: The name of the site to associate the firewall rule with.
        :param pulumi.Input[str] src_address: The source address for the firewall rule.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] src_firewall_group_ids: The source firewall group IDs for the firewall rule.
        :param pulumi.Input[str] src_mac: The source MAC address of the firewall rule.
        :param pulumi.Input[str] src_network_id: The source network ID for the firewall rule.
        :param pulumi.Input[str] src_network_type: The source network type of the firewall rule. Can be one of `ADDRv4` or `NETv4`. Defaults to `NETv4`.
        :param pulumi.Input[bool] state_established: Match where the state is established.
        :param pulumi.Input[bool] state_invalid: Match where the state is invalid.
        :param pulumi.Input[bool] state_new: Match where the state is new.
        :param pulumi.Input[bool] state_related: Match where the state is related.
        """
        pulumi.set(__self__, "action", action)
        pulumi.set(__self__, "protocol", protocol)
        pulumi.set(__self__, "rule_index", rule_index)
        pulumi.set(__self__, "ruleset", ruleset)
        if dst_address is not None:
            pulumi.set(__self__, "dst_address", dst_address)
        if dst_firewall_group_ids is not None:
            pulumi.set(__self__, "dst_firewall_group_ids", dst_firewall_group_ids)
        if dst_network_id is not None:
            pulumi.set(__self__, "dst_network_id", dst_network_id)
        if dst_network_type is not None:
            pulumi.set(__self__, "dst_network_type", dst_network_type)
        if dst_port is not None:
            pulumi.set(__self__, "dst_port", dst_port)
        if icmp_typename is not None:
            pulumi.set(__self__, "icmp_typename", icmp_typename)
        if ip_sec is not None:
            pulumi.set(__self__, "ip_sec", ip_sec)
        if logging is not None:
            pulumi.set(__self__, "logging", logging)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if site is not None:
            pulumi.set(__self__, "site", site)
        if src_address is not None:
            pulumi.set(__self__, "src_address", src_address)
        if src_firewall_group_ids is not None:
            pulumi.set(__self__, "src_firewall_group_ids", src_firewall_group_ids)
        if src_mac is not None:
            pulumi.set(__self__, "src_mac", src_mac)
        if src_network_id is not None:
            pulumi.set(__self__, "src_network_id", src_network_id)
        if src_network_type is not None:
            pulumi.set(__self__, "src_network_type", src_network_type)
        if state_established is not None:
            pulumi.set(__self__, "state_established", state_established)
        if state_invalid is not None:
            pulumi.set(__self__, "state_invalid", state_invalid)
        if state_new is not None:
            pulumi.set(__self__, "state_new", state_new)
        if state_related is not None:
            pulumi.set(__self__, "state_related", state_related)

    @property
    @pulumi.getter
    def action(self) -> pulumi.Input[str]:
        """
        The action of the firewall rule. Must be one of `drop`, `accept`, or `reject`.
        """
        return pulumi.get(self, "action")

    @action.setter
    def action(self, value: pulumi.Input[str]):
        pulumi.set(self, "action", value)

    @property
    @pulumi.getter
    def protocol(self) -> pulumi.Input[str]:
        """
        The protocol of the rule.
        """
        return pulumi.get(self, "protocol")

    @protocol.setter
    def protocol(self, value: pulumi.Input[str]):
        pulumi.set(self, "protocol", value)

    @property
    @pulumi.getter(name="ruleIndex")
    def rule_index(self) -> pulumi.Input[int]:
        """
        The index of the rule. Must be >= 2000 < 3000 or >= 4000 < 5000.
        """
        return pulumi.get(self, "rule_index")

    @rule_index.setter
    def rule_index(self, value: pulumi.Input[int]):
        pulumi.set(self, "rule_index", value)

    @property
    @pulumi.getter
    def ruleset(self) -> pulumi.Input[str]:
        """
        The ruleset for the rule. This is from the perspective of the security gateway. Must be one of `WAN_IN`, `WAN_OUT`, `WAN_LOCAL`, `LAN_IN`, `LAN_OUT`, `LAN_LOCAL`, `GUEST_IN`, `GUEST_OUT`, `GUEST_LOCAL`, `WANv6_IN`, `WANv6_OUT`, `WANv6_LOCAL`, `LANv6_IN`, `LANv6_OUT`, `LANv6_LOCAL`, `GUESTv6_IN`, `GUESTv6_OUT`, or `GUESTv6_LOCAL`.
        """
        return pulumi.get(self, "ruleset")

    @ruleset.setter
    def ruleset(self, value: pulumi.Input[str]):
        pulumi.set(self, "ruleset", value)

    @property
    @pulumi.getter(name="dstAddress")
    def dst_address(self) -> Optional[pulumi.Input[str]]:
        """
        The destination address of the firewall rule.
        """
        return pulumi.get(self, "dst_address")

    @dst_address.setter
    def dst_address(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "dst_address", value)

    @property
    @pulumi.getter(name="dstFirewallGroupIds")
    def dst_firewall_group_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The destination firewall group IDs of the firewall rule.
        """
        return pulumi.get(self, "dst_firewall_group_ids")

    @dst_firewall_group_ids.setter
    def dst_firewall_group_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "dst_firewall_group_ids", value)

    @property
    @pulumi.getter(name="dstNetworkId")
    def dst_network_id(self) -> Optional[pulumi.Input[str]]:
        """
        The destination network ID of the firewall rule.
        """
        return pulumi.get(self, "dst_network_id")

    @dst_network_id.setter
    def dst_network_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "dst_network_id", value)

    @property
    @pulumi.getter(name="dstNetworkType")
    def dst_network_type(self) -> Optional[pulumi.Input[str]]:
        """
        The destination network type of the firewall rule. Can be one of `ADDRv4` or `NETv4`. Defaults to `NETv4`.
        """
        return pulumi.get(self, "dst_network_type")

    @dst_network_type.setter
    def dst_network_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "dst_network_type", value)

    @property
    @pulumi.getter(name="dstPort")
    def dst_port(self) -> Optional[pulumi.Input[str]]:
        """
        The destination port of the firewall rule.
        """
        return pulumi.get(self, "dst_port")

    @dst_port.setter
    def dst_port(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "dst_port", value)

    @property
    @pulumi.getter(name="icmpTypename")
    def icmp_typename(self) -> Optional[pulumi.Input[str]]:
        """
        ICMP type name.
        """
        return pulumi.get(self, "icmp_typename")

    @icmp_typename.setter
    def icmp_typename(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "icmp_typename", value)

    @property
    @pulumi.getter(name="ipSec")
    def ip_sec(self) -> Optional[pulumi.Input[str]]:
        """
        Specify whether the rule matches on IPsec packets. Can be one of `match-ipset` or `match-none`.
        """
        return pulumi.get(self, "ip_sec")

    @ip_sec.setter
    def ip_sec(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ip_sec", value)

    @property
    @pulumi.getter
    def logging(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable logging for the firewall rule.
        """
        return pulumi.get(self, "logging")

    @logging.setter
    def logging(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "logging", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the firewall rule.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def site(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the site to associate the firewall rule with.
        """
        return pulumi.get(self, "site")

    @site.setter
    def site(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "site", value)

    @property
    @pulumi.getter(name="srcAddress")
    def src_address(self) -> Optional[pulumi.Input[str]]:
        """
        The source address for the firewall rule.
        """
        return pulumi.get(self, "src_address")

    @src_address.setter
    def src_address(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "src_address", value)

    @property
    @pulumi.getter(name="srcFirewallGroupIds")
    def src_firewall_group_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The source firewall group IDs for the firewall rule.
        """
        return pulumi.get(self, "src_firewall_group_ids")

    @src_firewall_group_ids.setter
    def src_firewall_group_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "src_firewall_group_ids", value)

    @property
    @pulumi.getter(name="srcMac")
    def src_mac(self) -> Optional[pulumi.Input[str]]:
        """
        The source MAC address of the firewall rule.
        """
        return pulumi.get(self, "src_mac")

    @src_mac.setter
    def src_mac(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "src_mac", value)

    @property
    @pulumi.getter(name="srcNetworkId")
    def src_network_id(self) -> Optional[pulumi.Input[str]]:
        """
        The source network ID for the firewall rule.
        """
        return pulumi.get(self, "src_network_id")

    @src_network_id.setter
    def src_network_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "src_network_id", value)

    @property
    @pulumi.getter(name="srcNetworkType")
    def src_network_type(self) -> Optional[pulumi.Input[str]]:
        """
        The source network type of the firewall rule. Can be one of `ADDRv4` or `NETv4`. Defaults to `NETv4`.
        """
        return pulumi.get(self, "src_network_type")

    @src_network_type.setter
    def src_network_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "src_network_type", value)

    @property
    @pulumi.getter(name="stateEstablished")
    def state_established(self) -> Optional[pulumi.Input[bool]]:
        """
        Match where the state is established.
        """
        return pulumi.get(self, "state_established")

    @state_established.setter
    def state_established(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "state_established", value)

    @property
    @pulumi.getter(name="stateInvalid")
    def state_invalid(self) -> Optional[pulumi.Input[bool]]:
        """
        Match where the state is invalid.
        """
        return pulumi.get(self, "state_invalid")

    @state_invalid.setter
    def state_invalid(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "state_invalid", value)

    @property
    @pulumi.getter(name="stateNew")
    def state_new(self) -> Optional[pulumi.Input[bool]]:
        """
        Match where the state is new.
        """
        return pulumi.get(self, "state_new")

    @state_new.setter
    def state_new(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "state_new", value)

    @property
    @pulumi.getter(name="stateRelated")
    def state_related(self) -> Optional[pulumi.Input[bool]]:
        """
        Match where the state is related.
        """
        return pulumi.get(self, "state_related")

    @state_related.setter
    def state_related(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "state_related", value)


@pulumi.input_type
class _RuleState:
    def __init__(__self__, *,
                 action: Optional[pulumi.Input[str]] = None,
                 dst_address: Optional[pulumi.Input[str]] = None,
                 dst_firewall_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 dst_network_id: Optional[pulumi.Input[str]] = None,
                 dst_network_type: Optional[pulumi.Input[str]] = None,
                 dst_port: Optional[pulumi.Input[str]] = None,
                 icmp_typename: Optional[pulumi.Input[str]] = None,
                 ip_sec: Optional[pulumi.Input[str]] = None,
                 logging: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 protocol: Optional[pulumi.Input[str]] = None,
                 rule_index: Optional[pulumi.Input[int]] = None,
                 ruleset: Optional[pulumi.Input[str]] = None,
                 site: Optional[pulumi.Input[str]] = None,
                 src_address: Optional[pulumi.Input[str]] = None,
                 src_firewall_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 src_mac: Optional[pulumi.Input[str]] = None,
                 src_network_id: Optional[pulumi.Input[str]] = None,
                 src_network_type: Optional[pulumi.Input[str]] = None,
                 state_established: Optional[pulumi.Input[bool]] = None,
                 state_invalid: Optional[pulumi.Input[bool]] = None,
                 state_new: Optional[pulumi.Input[bool]] = None,
                 state_related: Optional[pulumi.Input[bool]] = None):
        """
        Input properties used for looking up and filtering Rule resources.
        :param pulumi.Input[str] action: The action of the firewall rule. Must be one of `drop`, `accept`, or `reject`.
        :param pulumi.Input[str] dst_address: The destination address of the firewall rule.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] dst_firewall_group_ids: The destination firewall group IDs of the firewall rule.
        :param pulumi.Input[str] dst_network_id: The destination network ID of the firewall rule.
        :param pulumi.Input[str] dst_network_type: The destination network type of the firewall rule. Can be one of `ADDRv4` or `NETv4`. Defaults to `NETv4`.
        :param pulumi.Input[str] dst_port: The destination port of the firewall rule.
        :param pulumi.Input[str] icmp_typename: ICMP type name.
        :param pulumi.Input[str] ip_sec: Specify whether the rule matches on IPsec packets. Can be one of `match-ipset` or `match-none`.
        :param pulumi.Input[bool] logging: Enable logging for the firewall rule.
        :param pulumi.Input[str] name: The name of the firewall rule.
        :param pulumi.Input[str] protocol: The protocol of the rule.
        :param pulumi.Input[int] rule_index: The index of the rule. Must be >= 2000 < 3000 or >= 4000 < 5000.
        :param pulumi.Input[str] ruleset: The ruleset for the rule. This is from the perspective of the security gateway. Must be one of `WAN_IN`, `WAN_OUT`, `WAN_LOCAL`, `LAN_IN`, `LAN_OUT`, `LAN_LOCAL`, `GUEST_IN`, `GUEST_OUT`, `GUEST_LOCAL`, `WANv6_IN`, `WANv6_OUT`, `WANv6_LOCAL`, `LANv6_IN`, `LANv6_OUT`, `LANv6_LOCAL`, `GUESTv6_IN`, `GUESTv6_OUT`, or `GUESTv6_LOCAL`.
        :param pulumi.Input[str] site: The name of the site to associate the firewall rule with.
        :param pulumi.Input[str] src_address: The source address for the firewall rule.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] src_firewall_group_ids: The source firewall group IDs for the firewall rule.
        :param pulumi.Input[str] src_mac: The source MAC address of the firewall rule.
        :param pulumi.Input[str] src_network_id: The source network ID for the firewall rule.
        :param pulumi.Input[str] src_network_type: The source network type of the firewall rule. Can be one of `ADDRv4` or `NETv4`. Defaults to `NETv4`.
        :param pulumi.Input[bool] state_established: Match where the state is established.
        :param pulumi.Input[bool] state_invalid: Match where the state is invalid.
        :param pulumi.Input[bool] state_new: Match where the state is new.
        :param pulumi.Input[bool] state_related: Match where the state is related.
        """
        if action is not None:
            pulumi.set(__self__, "action", action)
        if dst_address is not None:
            pulumi.set(__self__, "dst_address", dst_address)
        if dst_firewall_group_ids is not None:
            pulumi.set(__self__, "dst_firewall_group_ids", dst_firewall_group_ids)
        if dst_network_id is not None:
            pulumi.set(__self__, "dst_network_id", dst_network_id)
        if dst_network_type is not None:
            pulumi.set(__self__, "dst_network_type", dst_network_type)
        if dst_port is not None:
            pulumi.set(__self__, "dst_port", dst_port)
        if icmp_typename is not None:
            pulumi.set(__self__, "icmp_typename", icmp_typename)
        if ip_sec is not None:
            pulumi.set(__self__, "ip_sec", ip_sec)
        if logging is not None:
            pulumi.set(__self__, "logging", logging)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if protocol is not None:
            pulumi.set(__self__, "protocol", protocol)
        if rule_index is not None:
            pulumi.set(__self__, "rule_index", rule_index)
        if ruleset is not None:
            pulumi.set(__self__, "ruleset", ruleset)
        if site is not None:
            pulumi.set(__self__, "site", site)
        if src_address is not None:
            pulumi.set(__self__, "src_address", src_address)
        if src_firewall_group_ids is not None:
            pulumi.set(__self__, "src_firewall_group_ids", src_firewall_group_ids)
        if src_mac is not None:
            pulumi.set(__self__, "src_mac", src_mac)
        if src_network_id is not None:
            pulumi.set(__self__, "src_network_id", src_network_id)
        if src_network_type is not None:
            pulumi.set(__self__, "src_network_type", src_network_type)
        if state_established is not None:
            pulumi.set(__self__, "state_established", state_established)
        if state_invalid is not None:
            pulumi.set(__self__, "state_invalid", state_invalid)
        if state_new is not None:
            pulumi.set(__self__, "state_new", state_new)
        if state_related is not None:
            pulumi.set(__self__, "state_related", state_related)

    @property
    @pulumi.getter
    def action(self) -> Optional[pulumi.Input[str]]:
        """
        The action of the firewall rule. Must be one of `drop`, `accept`, or `reject`.
        """
        return pulumi.get(self, "action")

    @action.setter
    def action(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "action", value)

    @property
    @pulumi.getter(name="dstAddress")
    def dst_address(self) -> Optional[pulumi.Input[str]]:
        """
        The destination address of the firewall rule.
        """
        return pulumi.get(self, "dst_address")

    @dst_address.setter
    def dst_address(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "dst_address", value)

    @property
    @pulumi.getter(name="dstFirewallGroupIds")
    def dst_firewall_group_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The destination firewall group IDs of the firewall rule.
        """
        return pulumi.get(self, "dst_firewall_group_ids")

    @dst_firewall_group_ids.setter
    def dst_firewall_group_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "dst_firewall_group_ids", value)

    @property
    @pulumi.getter(name="dstNetworkId")
    def dst_network_id(self) -> Optional[pulumi.Input[str]]:
        """
        The destination network ID of the firewall rule.
        """
        return pulumi.get(self, "dst_network_id")

    @dst_network_id.setter
    def dst_network_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "dst_network_id", value)

    @property
    @pulumi.getter(name="dstNetworkType")
    def dst_network_type(self) -> Optional[pulumi.Input[str]]:
        """
        The destination network type of the firewall rule. Can be one of `ADDRv4` or `NETv4`. Defaults to `NETv4`.
        """
        return pulumi.get(self, "dst_network_type")

    @dst_network_type.setter
    def dst_network_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "dst_network_type", value)

    @property
    @pulumi.getter(name="dstPort")
    def dst_port(self) -> Optional[pulumi.Input[str]]:
        """
        The destination port of the firewall rule.
        """
        return pulumi.get(self, "dst_port")

    @dst_port.setter
    def dst_port(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "dst_port", value)

    @property
    @pulumi.getter(name="icmpTypename")
    def icmp_typename(self) -> Optional[pulumi.Input[str]]:
        """
        ICMP type name.
        """
        return pulumi.get(self, "icmp_typename")

    @icmp_typename.setter
    def icmp_typename(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "icmp_typename", value)

    @property
    @pulumi.getter(name="ipSec")
    def ip_sec(self) -> Optional[pulumi.Input[str]]:
        """
        Specify whether the rule matches on IPsec packets. Can be one of `match-ipset` or `match-none`.
        """
        return pulumi.get(self, "ip_sec")

    @ip_sec.setter
    def ip_sec(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ip_sec", value)

    @property
    @pulumi.getter
    def logging(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable logging for the firewall rule.
        """
        return pulumi.get(self, "logging")

    @logging.setter
    def logging(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "logging", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the firewall rule.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def protocol(self) -> Optional[pulumi.Input[str]]:
        """
        The protocol of the rule.
        """
        return pulumi.get(self, "protocol")

    @protocol.setter
    def protocol(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "protocol", value)

    @property
    @pulumi.getter(name="ruleIndex")
    def rule_index(self) -> Optional[pulumi.Input[int]]:
        """
        The index of the rule. Must be >= 2000 < 3000 or >= 4000 < 5000.
        """
        return pulumi.get(self, "rule_index")

    @rule_index.setter
    def rule_index(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "rule_index", value)

    @property
    @pulumi.getter
    def ruleset(self) -> Optional[pulumi.Input[str]]:
        """
        The ruleset for the rule. This is from the perspective of the security gateway. Must be one of `WAN_IN`, `WAN_OUT`, `WAN_LOCAL`, `LAN_IN`, `LAN_OUT`, `LAN_LOCAL`, `GUEST_IN`, `GUEST_OUT`, `GUEST_LOCAL`, `WANv6_IN`, `WANv6_OUT`, `WANv6_LOCAL`, `LANv6_IN`, `LANv6_OUT`, `LANv6_LOCAL`, `GUESTv6_IN`, `GUESTv6_OUT`, or `GUESTv6_LOCAL`.
        """
        return pulumi.get(self, "ruleset")

    @ruleset.setter
    def ruleset(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ruleset", value)

    @property
    @pulumi.getter
    def site(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the site to associate the firewall rule with.
        """
        return pulumi.get(self, "site")

    @site.setter
    def site(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "site", value)

    @property
    @pulumi.getter(name="srcAddress")
    def src_address(self) -> Optional[pulumi.Input[str]]:
        """
        The source address for the firewall rule.
        """
        return pulumi.get(self, "src_address")

    @src_address.setter
    def src_address(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "src_address", value)

    @property
    @pulumi.getter(name="srcFirewallGroupIds")
    def src_firewall_group_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The source firewall group IDs for the firewall rule.
        """
        return pulumi.get(self, "src_firewall_group_ids")

    @src_firewall_group_ids.setter
    def src_firewall_group_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "src_firewall_group_ids", value)

    @property
    @pulumi.getter(name="srcMac")
    def src_mac(self) -> Optional[pulumi.Input[str]]:
        """
        The source MAC address of the firewall rule.
        """
        return pulumi.get(self, "src_mac")

    @src_mac.setter
    def src_mac(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "src_mac", value)

    @property
    @pulumi.getter(name="srcNetworkId")
    def src_network_id(self) -> Optional[pulumi.Input[str]]:
        """
        The source network ID for the firewall rule.
        """
        return pulumi.get(self, "src_network_id")

    @src_network_id.setter
    def src_network_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "src_network_id", value)

    @property
    @pulumi.getter(name="srcNetworkType")
    def src_network_type(self) -> Optional[pulumi.Input[str]]:
        """
        The source network type of the firewall rule. Can be one of `ADDRv4` or `NETv4`. Defaults to `NETv4`.
        """
        return pulumi.get(self, "src_network_type")

    @src_network_type.setter
    def src_network_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "src_network_type", value)

    @property
    @pulumi.getter(name="stateEstablished")
    def state_established(self) -> Optional[pulumi.Input[bool]]:
        """
        Match where the state is established.
        """
        return pulumi.get(self, "state_established")

    @state_established.setter
    def state_established(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "state_established", value)

    @property
    @pulumi.getter(name="stateInvalid")
    def state_invalid(self) -> Optional[pulumi.Input[bool]]:
        """
        Match where the state is invalid.
        """
        return pulumi.get(self, "state_invalid")

    @state_invalid.setter
    def state_invalid(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "state_invalid", value)

    @property
    @pulumi.getter(name="stateNew")
    def state_new(self) -> Optional[pulumi.Input[bool]]:
        """
        Match where the state is new.
        """
        return pulumi.get(self, "state_new")

    @state_new.setter
    def state_new(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "state_new", value)

    @property
    @pulumi.getter(name="stateRelated")
    def state_related(self) -> Optional[pulumi.Input[bool]]:
        """
        Match where the state is related.
        """
        return pulumi.get(self, "state_related")

    @state_related.setter
    def state_related(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "state_related", value)


class Rule(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 action: Optional[pulumi.Input[str]] = None,
                 dst_address: Optional[pulumi.Input[str]] = None,
                 dst_firewall_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 dst_network_id: Optional[pulumi.Input[str]] = None,
                 dst_network_type: Optional[pulumi.Input[str]] = None,
                 dst_port: Optional[pulumi.Input[str]] = None,
                 icmp_typename: Optional[pulumi.Input[str]] = None,
                 ip_sec: Optional[pulumi.Input[str]] = None,
                 logging: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 protocol: Optional[pulumi.Input[str]] = None,
                 rule_index: Optional[pulumi.Input[int]] = None,
                 ruleset: Optional[pulumi.Input[str]] = None,
                 site: Optional[pulumi.Input[str]] = None,
                 src_address: Optional[pulumi.Input[str]] = None,
                 src_firewall_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 src_mac: Optional[pulumi.Input[str]] = None,
                 src_network_id: Optional[pulumi.Input[str]] = None,
                 src_network_type: Optional[pulumi.Input[str]] = None,
                 state_established: Optional[pulumi.Input[bool]] = None,
                 state_invalid: Optional[pulumi.Input[bool]] = None,
                 state_new: Optional[pulumi.Input[bool]] = None,
                 state_related: Optional[pulumi.Input[bool]] = None,
                 __props__=None):
        """
        `firewall.Rule` manages an individual firewall rule on the gateway.

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_unifi as unifi

        config = pulumi.Config()
        ip_address = config.require("ipAddress")
        drop_all = unifi.firewall.Rule("dropAll",
            action="drop",
            ruleset="LAN_IN",
            rule_index=2011,
            protocol="all",
            dst_address=ip_address)
        ```

        ## Import

        import using the ID from the controller API/UI

        ```sh
         $ pulumi import unifi:firewall/rule:Rule my_rule 5f7080eb6b8969064f80494f
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] action: The action of the firewall rule. Must be one of `drop`, `accept`, or `reject`.
        :param pulumi.Input[str] dst_address: The destination address of the firewall rule.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] dst_firewall_group_ids: The destination firewall group IDs of the firewall rule.
        :param pulumi.Input[str] dst_network_id: The destination network ID of the firewall rule.
        :param pulumi.Input[str] dst_network_type: The destination network type of the firewall rule. Can be one of `ADDRv4` or `NETv4`. Defaults to `NETv4`.
        :param pulumi.Input[str] dst_port: The destination port of the firewall rule.
        :param pulumi.Input[str] icmp_typename: ICMP type name.
        :param pulumi.Input[str] ip_sec: Specify whether the rule matches on IPsec packets. Can be one of `match-ipset` or `match-none`.
        :param pulumi.Input[bool] logging: Enable logging for the firewall rule.
        :param pulumi.Input[str] name: The name of the firewall rule.
        :param pulumi.Input[str] protocol: The protocol of the rule.
        :param pulumi.Input[int] rule_index: The index of the rule. Must be >= 2000 < 3000 or >= 4000 < 5000.
        :param pulumi.Input[str] ruleset: The ruleset for the rule. This is from the perspective of the security gateway. Must be one of `WAN_IN`, `WAN_OUT`, `WAN_LOCAL`, `LAN_IN`, `LAN_OUT`, `LAN_LOCAL`, `GUEST_IN`, `GUEST_OUT`, `GUEST_LOCAL`, `WANv6_IN`, `WANv6_OUT`, `WANv6_LOCAL`, `LANv6_IN`, `LANv6_OUT`, `LANv6_LOCAL`, `GUESTv6_IN`, `GUESTv6_OUT`, or `GUESTv6_LOCAL`.
        :param pulumi.Input[str] site: The name of the site to associate the firewall rule with.
        :param pulumi.Input[str] src_address: The source address for the firewall rule.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] src_firewall_group_ids: The source firewall group IDs for the firewall rule.
        :param pulumi.Input[str] src_mac: The source MAC address of the firewall rule.
        :param pulumi.Input[str] src_network_id: The source network ID for the firewall rule.
        :param pulumi.Input[str] src_network_type: The source network type of the firewall rule. Can be one of `ADDRv4` or `NETv4`. Defaults to `NETv4`.
        :param pulumi.Input[bool] state_established: Match where the state is established.
        :param pulumi.Input[bool] state_invalid: Match where the state is invalid.
        :param pulumi.Input[bool] state_new: Match where the state is new.
        :param pulumi.Input[bool] state_related: Match where the state is related.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: RuleArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        `firewall.Rule` manages an individual firewall rule on the gateway.

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_unifi as unifi

        config = pulumi.Config()
        ip_address = config.require("ipAddress")
        drop_all = unifi.firewall.Rule("dropAll",
            action="drop",
            ruleset="LAN_IN",
            rule_index=2011,
            protocol="all",
            dst_address=ip_address)
        ```

        ## Import

        import using the ID from the controller API/UI

        ```sh
         $ pulumi import unifi:firewall/rule:Rule my_rule 5f7080eb6b8969064f80494f
        ```

        :param str resource_name: The name of the resource.
        :param RuleArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RuleArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 action: Optional[pulumi.Input[str]] = None,
                 dst_address: Optional[pulumi.Input[str]] = None,
                 dst_firewall_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 dst_network_id: Optional[pulumi.Input[str]] = None,
                 dst_network_type: Optional[pulumi.Input[str]] = None,
                 dst_port: Optional[pulumi.Input[str]] = None,
                 icmp_typename: Optional[pulumi.Input[str]] = None,
                 ip_sec: Optional[pulumi.Input[str]] = None,
                 logging: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 protocol: Optional[pulumi.Input[str]] = None,
                 rule_index: Optional[pulumi.Input[int]] = None,
                 ruleset: Optional[pulumi.Input[str]] = None,
                 site: Optional[pulumi.Input[str]] = None,
                 src_address: Optional[pulumi.Input[str]] = None,
                 src_firewall_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 src_mac: Optional[pulumi.Input[str]] = None,
                 src_network_id: Optional[pulumi.Input[str]] = None,
                 src_network_type: Optional[pulumi.Input[str]] = None,
                 state_established: Optional[pulumi.Input[bool]] = None,
                 state_invalid: Optional[pulumi.Input[bool]] = None,
                 state_new: Optional[pulumi.Input[bool]] = None,
                 state_related: Optional[pulumi.Input[bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RuleArgs.__new__(RuleArgs)

            if action is None and not opts.urn:
                raise TypeError("Missing required property 'action'")
            __props__.__dict__["action"] = action
            __props__.__dict__["dst_address"] = dst_address
            __props__.__dict__["dst_firewall_group_ids"] = dst_firewall_group_ids
            __props__.__dict__["dst_network_id"] = dst_network_id
            __props__.__dict__["dst_network_type"] = dst_network_type
            __props__.__dict__["dst_port"] = dst_port
            __props__.__dict__["icmp_typename"] = icmp_typename
            __props__.__dict__["ip_sec"] = ip_sec
            __props__.__dict__["logging"] = logging
            __props__.__dict__["name"] = name
            if protocol is None and not opts.urn:
                raise TypeError("Missing required property 'protocol'")
            __props__.__dict__["protocol"] = protocol
            if rule_index is None and not opts.urn:
                raise TypeError("Missing required property 'rule_index'")
            __props__.__dict__["rule_index"] = rule_index
            if ruleset is None and not opts.urn:
                raise TypeError("Missing required property 'ruleset'")
            __props__.__dict__["ruleset"] = ruleset
            __props__.__dict__["site"] = site
            __props__.__dict__["src_address"] = src_address
            __props__.__dict__["src_firewall_group_ids"] = src_firewall_group_ids
            __props__.__dict__["src_mac"] = src_mac
            __props__.__dict__["src_network_id"] = src_network_id
            __props__.__dict__["src_network_type"] = src_network_type
            __props__.__dict__["state_established"] = state_established
            __props__.__dict__["state_invalid"] = state_invalid
            __props__.__dict__["state_new"] = state_new
            __props__.__dict__["state_related"] = state_related
        super(Rule, __self__).__init__(
            'unifi:firewall/rule:Rule',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            action: Optional[pulumi.Input[str]] = None,
            dst_address: Optional[pulumi.Input[str]] = None,
            dst_firewall_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            dst_network_id: Optional[pulumi.Input[str]] = None,
            dst_network_type: Optional[pulumi.Input[str]] = None,
            dst_port: Optional[pulumi.Input[str]] = None,
            icmp_typename: Optional[pulumi.Input[str]] = None,
            ip_sec: Optional[pulumi.Input[str]] = None,
            logging: Optional[pulumi.Input[bool]] = None,
            name: Optional[pulumi.Input[str]] = None,
            protocol: Optional[pulumi.Input[str]] = None,
            rule_index: Optional[pulumi.Input[int]] = None,
            ruleset: Optional[pulumi.Input[str]] = None,
            site: Optional[pulumi.Input[str]] = None,
            src_address: Optional[pulumi.Input[str]] = None,
            src_firewall_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            src_mac: Optional[pulumi.Input[str]] = None,
            src_network_id: Optional[pulumi.Input[str]] = None,
            src_network_type: Optional[pulumi.Input[str]] = None,
            state_established: Optional[pulumi.Input[bool]] = None,
            state_invalid: Optional[pulumi.Input[bool]] = None,
            state_new: Optional[pulumi.Input[bool]] = None,
            state_related: Optional[pulumi.Input[bool]] = None) -> 'Rule':
        """
        Get an existing Rule resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] action: The action of the firewall rule. Must be one of `drop`, `accept`, or `reject`.
        :param pulumi.Input[str] dst_address: The destination address of the firewall rule.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] dst_firewall_group_ids: The destination firewall group IDs of the firewall rule.
        :param pulumi.Input[str] dst_network_id: The destination network ID of the firewall rule.
        :param pulumi.Input[str] dst_network_type: The destination network type of the firewall rule. Can be one of `ADDRv4` or `NETv4`. Defaults to `NETv4`.
        :param pulumi.Input[str] dst_port: The destination port of the firewall rule.
        :param pulumi.Input[str] icmp_typename: ICMP type name.
        :param pulumi.Input[str] ip_sec: Specify whether the rule matches on IPsec packets. Can be one of `match-ipset` or `match-none`.
        :param pulumi.Input[bool] logging: Enable logging for the firewall rule.
        :param pulumi.Input[str] name: The name of the firewall rule.
        :param pulumi.Input[str] protocol: The protocol of the rule.
        :param pulumi.Input[int] rule_index: The index of the rule. Must be >= 2000 < 3000 or >= 4000 < 5000.
        :param pulumi.Input[str] ruleset: The ruleset for the rule. This is from the perspective of the security gateway. Must be one of `WAN_IN`, `WAN_OUT`, `WAN_LOCAL`, `LAN_IN`, `LAN_OUT`, `LAN_LOCAL`, `GUEST_IN`, `GUEST_OUT`, `GUEST_LOCAL`, `WANv6_IN`, `WANv6_OUT`, `WANv6_LOCAL`, `LANv6_IN`, `LANv6_OUT`, `LANv6_LOCAL`, `GUESTv6_IN`, `GUESTv6_OUT`, or `GUESTv6_LOCAL`.
        :param pulumi.Input[str] site: The name of the site to associate the firewall rule with.
        :param pulumi.Input[str] src_address: The source address for the firewall rule.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] src_firewall_group_ids: The source firewall group IDs for the firewall rule.
        :param pulumi.Input[str] src_mac: The source MAC address of the firewall rule.
        :param pulumi.Input[str] src_network_id: The source network ID for the firewall rule.
        :param pulumi.Input[str] src_network_type: The source network type of the firewall rule. Can be one of `ADDRv4` or `NETv4`. Defaults to `NETv4`.
        :param pulumi.Input[bool] state_established: Match where the state is established.
        :param pulumi.Input[bool] state_invalid: Match where the state is invalid.
        :param pulumi.Input[bool] state_new: Match where the state is new.
        :param pulumi.Input[bool] state_related: Match where the state is related.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RuleState.__new__(_RuleState)

        __props__.__dict__["action"] = action
        __props__.__dict__["dst_address"] = dst_address
        __props__.__dict__["dst_firewall_group_ids"] = dst_firewall_group_ids
        __props__.__dict__["dst_network_id"] = dst_network_id
        __props__.__dict__["dst_network_type"] = dst_network_type
        __props__.__dict__["dst_port"] = dst_port
        __props__.__dict__["icmp_typename"] = icmp_typename
        __props__.__dict__["ip_sec"] = ip_sec
        __props__.__dict__["logging"] = logging
        __props__.__dict__["name"] = name
        __props__.__dict__["protocol"] = protocol
        __props__.__dict__["rule_index"] = rule_index
        __props__.__dict__["ruleset"] = ruleset
        __props__.__dict__["site"] = site
        __props__.__dict__["src_address"] = src_address
        __props__.__dict__["src_firewall_group_ids"] = src_firewall_group_ids
        __props__.__dict__["src_mac"] = src_mac
        __props__.__dict__["src_network_id"] = src_network_id
        __props__.__dict__["src_network_type"] = src_network_type
        __props__.__dict__["state_established"] = state_established
        __props__.__dict__["state_invalid"] = state_invalid
        __props__.__dict__["state_new"] = state_new
        __props__.__dict__["state_related"] = state_related
        return Rule(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def action(self) -> pulumi.Output[str]:
        """
        The action of the firewall rule. Must be one of `drop`, `accept`, or `reject`.
        """
        return pulumi.get(self, "action")

    @property
    @pulumi.getter(name="dstAddress")
    def dst_address(self) -> pulumi.Output[Optional[str]]:
        """
        The destination address of the firewall rule.
        """
        return pulumi.get(self, "dst_address")

    @property
    @pulumi.getter(name="dstFirewallGroupIds")
    def dst_firewall_group_ids(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        The destination firewall group IDs of the firewall rule.
        """
        return pulumi.get(self, "dst_firewall_group_ids")

    @property
    @pulumi.getter(name="dstNetworkId")
    def dst_network_id(self) -> pulumi.Output[Optional[str]]:
        """
        The destination network ID of the firewall rule.
        """
        return pulumi.get(self, "dst_network_id")

    @property
    @pulumi.getter(name="dstNetworkType")
    def dst_network_type(self) -> pulumi.Output[Optional[str]]:
        """
        The destination network type of the firewall rule. Can be one of `ADDRv4` or `NETv4`. Defaults to `NETv4`.
        """
        return pulumi.get(self, "dst_network_type")

    @property
    @pulumi.getter(name="dstPort")
    def dst_port(self) -> pulumi.Output[Optional[str]]:
        """
        The destination port of the firewall rule.
        """
        return pulumi.get(self, "dst_port")

    @property
    @pulumi.getter(name="icmpTypename")
    def icmp_typename(self) -> pulumi.Output[Optional[str]]:
        """
        ICMP type name.
        """
        return pulumi.get(self, "icmp_typename")

    @property
    @pulumi.getter(name="ipSec")
    def ip_sec(self) -> pulumi.Output[Optional[str]]:
        """
        Specify whether the rule matches on IPsec packets. Can be one of `match-ipset` or `match-none`.
        """
        return pulumi.get(self, "ip_sec")

    @property
    @pulumi.getter
    def logging(self) -> pulumi.Output[Optional[bool]]:
        """
        Enable logging for the firewall rule.
        """
        return pulumi.get(self, "logging")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The name of the firewall rule.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def protocol(self) -> pulumi.Output[str]:
        """
        The protocol of the rule.
        """
        return pulumi.get(self, "protocol")

    @property
    @pulumi.getter(name="ruleIndex")
    def rule_index(self) -> pulumi.Output[int]:
        """
        The index of the rule. Must be >= 2000 < 3000 or >= 4000 < 5000.
        """
        return pulumi.get(self, "rule_index")

    @property
    @pulumi.getter
    def ruleset(self) -> pulumi.Output[str]:
        """
        The ruleset for the rule. This is from the perspective of the security gateway. Must be one of `WAN_IN`, `WAN_OUT`, `WAN_LOCAL`, `LAN_IN`, `LAN_OUT`, `LAN_LOCAL`, `GUEST_IN`, `GUEST_OUT`, `GUEST_LOCAL`, `WANv6_IN`, `WANv6_OUT`, `WANv6_LOCAL`, `LANv6_IN`, `LANv6_OUT`, `LANv6_LOCAL`, `GUESTv6_IN`, `GUESTv6_OUT`, or `GUESTv6_LOCAL`.
        """
        return pulumi.get(self, "ruleset")

    @property
    @pulumi.getter
    def site(self) -> pulumi.Output[str]:
        """
        The name of the site to associate the firewall rule with.
        """
        return pulumi.get(self, "site")

    @property
    @pulumi.getter(name="srcAddress")
    def src_address(self) -> pulumi.Output[Optional[str]]:
        """
        The source address for the firewall rule.
        """
        return pulumi.get(self, "src_address")

    @property
    @pulumi.getter(name="srcFirewallGroupIds")
    def src_firewall_group_ids(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        The source firewall group IDs for the firewall rule.
        """
        return pulumi.get(self, "src_firewall_group_ids")

    @property
    @pulumi.getter(name="srcMac")
    def src_mac(self) -> pulumi.Output[Optional[str]]:
        """
        The source MAC address of the firewall rule.
        """
        return pulumi.get(self, "src_mac")

    @property
    @pulumi.getter(name="srcNetworkId")
    def src_network_id(self) -> pulumi.Output[Optional[str]]:
        """
        The source network ID for the firewall rule.
        """
        return pulumi.get(self, "src_network_id")

    @property
    @pulumi.getter(name="srcNetworkType")
    def src_network_type(self) -> pulumi.Output[Optional[str]]:
        """
        The source network type of the firewall rule. Can be one of `ADDRv4` or `NETv4`. Defaults to `NETv4`.
        """
        return pulumi.get(self, "src_network_type")

    @property
    @pulumi.getter(name="stateEstablished")
    def state_established(self) -> pulumi.Output[Optional[bool]]:
        """
        Match where the state is established.
        """
        return pulumi.get(self, "state_established")

    @property
    @pulumi.getter(name="stateInvalid")
    def state_invalid(self) -> pulumi.Output[Optional[bool]]:
        """
        Match where the state is invalid.
        """
        return pulumi.get(self, "state_invalid")

    @property
    @pulumi.getter(name="stateNew")
    def state_new(self) -> pulumi.Output[Optional[bool]]:
        """
        Match where the state is new.
        """
        return pulumi.get(self, "state_new")

    @property
    @pulumi.getter(name="stateRelated")
    def state_related(self) -> pulumi.Output[Optional[bool]]:
        """
        Match where the state is related.
        """
        return pulumi.get(self, "state_related")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['ForwardArgs', 'Forward']

@pulumi.input_type
class ForwardArgs:
    def __init__(__self__, *,
                 dst_port: Optional[pulumi.Input[str]] = None,
                 enabled: Optional[pulumi.Input[bool]] = None,
                 fwd_ip: Optional[pulumi.Input[str]] = None,
                 fwd_port: Optional[pulumi.Input[str]] = None,
                 log: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 port_forward_interface: Optional[pulumi.Input[str]] = None,
                 protocol: Optional[pulumi.Input[str]] = None,
                 site: Optional[pulumi.Input[str]] = None,
                 src_ip: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a Forward resource.
        :param pulumi.Input[str] dst_port: The destination port for the forwarding.
        :param pulumi.Input[bool] enabled: Specifies whether the port forwarding rule is enabled or not. This will attribute will be removed in a future release. Instead of disabling a port forwarding rule you can remove it from your configuration.
        :param pulumi.Input[str] fwd_ip: The IPv4 address to forward traffic to.
        :param pulumi.Input[str] fwd_port: The port to forward traffic to.
        :param pulumi.Input[bool] log: Specifies whether to log forwarded traffic or not. Defaults to `false`.
        :param pulumi.Input[str] name: The name of the port forwarding rule.
        :param pulumi.Input[str] port_forward_interface: The port forwarding interface. Can be `wan`, `wan2`, or `both`.
        :param pulumi.Input[str] protocol: The protocol for the port forwarding rule. Can be `tcp`, `udp`, or `tcp_udp`. Defaults to `tcp_udp`.
        :param pulumi.Input[str] site: The name of the site to associate the port forwarding rule with.
        :param pulumi.Input[str] src_ip: The source IPv4 address (or CIDR) of the port forwarding rule. For all traffic, specify `any`. Defaults to `any`.
        """
        if dst_port is not None:
            pulumi.set(__self__, "dst_port", dst_port)
        if enabled is not None:
            warnings.warn("""This will attribute will be removed in a future release. Instead of disabling a port forwarding rule you can remove it from your configuration.""", DeprecationWarning)
            pulumi.log.warn("""enabled is deprecated: This will attribute will be removed in a future release. Instead of disabling a port forwarding rule you can remove it from your configuration.""")
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if fwd_ip is not None:
            pulumi.set(__self__, "fwd_ip", fwd_ip)
        if fwd_port is not None:
            pulumi.set(__self__, "fwd_port", fwd_port)
        if log is not None:
            pulumi.set(__self__, "log", log)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if port_forward_interface is not None:
            pulumi.set(__self__, "port_forward_interface", port_forward_interface)
        if protocol is not None:
            pulumi.set(__self__, "protocol", protocol)
        if site is not None:
            pulumi.set(__self__, "site", site)
        if src_ip is not None:
            pulumi.set(__self__, "src_ip", src_ip)

    @property
    @pulumi.getter(name="dstPort")
    def dst_port(self) -> Optional[pulumi.Input[str]]:
        """
        The destination port for the forwarding.
        """
        return pulumi.get(self, "dst_port")

    @dst_port.setter
    def dst_port(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "dst_port", value)

    @property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Specifies whether the port forwarding rule is enabled or not. This will attribute will be removed in a future release. Instead of disabling a port forwarding rule you can remove it from your configuration.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "enabled", value)

    @property
    @pulumi.getter(name="fwdIp")
    def fwd_ip(self) -> Optional[pulumi.Input[str]]:
        """
        The IPv4 address to forward traffic to.
        """
        return pulumi.get(self, "fwd_ip")

    @fwd_ip.setter
    def fwd_ip(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "fwd_ip", value)

    @property
    @pulumi.getter(name="fwdPort")
    def fwd_port(self) -> Optional[pulumi.Input[str]]:
        """
        The port to forward traffic to.
        """
        return pulumi.get(self, "fwd_port")

    @fwd_port.setter
    def fwd_port(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "fwd_port", value)

    @property
    @pulumi.getter
    def log(self) -> Optional[pulumi.Input[bool]]:
        """
        Specifies whether to log forwarded traffic or not. Defaults to `false`.
        """
        return pulumi.get(self, "log")

    @log.setter
    def log(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "log", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the port forwarding rule.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="portForwardInterface")
    def port_forward_interface(self) -> Optional[pulumi.Input[str]]:
        """
        The port forwarding interface. Can be `wan`, `wan2`, or `both`.
        """
        return pulumi.get(self, "port_forward_interface")

    @port_forward_interface.setter
    def port_forward_interface(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "port_forward_interface", value)

    @property
    @pulumi.getter
    def protocol(self) -> Optional[pulumi.Input[str]]:
        """
        The protocol for the port forwarding rule. Can be `tcp`, `udp`, or `tcp_udp`. Defaults to `tcp_udp`.
        """
        return pulumi.get(self, "protocol")

    @protocol.setter
    def protocol(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "protocol", value)

    @property
    @pulumi.getter
    def site(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the site to associate the port forwarding rule with.
        """
        return pulumi.get(self, "site")

    @site.setter
    def site(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "site", value)

    @property
    @pulumi.getter(name="srcIp")
    def src_ip(self) -> Optional[pulumi.Input[str]]:
        """
        The source IPv4 address (or CIDR) of the port forwarding rule. For all traffic, specify `any`. Defaults to `any`.
        """
        return pulumi.get(self, "src_ip")

    @src_ip.setter
    def src_ip(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "src_ip", value)


@pulumi.input_type
class _ForwardState:
    def __init__(__self__, *,
                 dst_port: Optional[pulumi.Input[str]] = None,
                 enabled: Optional[pulumi.Input[bool]] = None,
                 fwd_ip: Optional[pulumi.Input[str]] = None,
                 fwd_port: Optional[pulumi.Input[str]] = None,
                 log: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 port_forward_interface: Optional[pulumi.Input[str]] = None,
                 protocol: Optional[pulumi.Input[str]] = None,
                 site: Optional[pulumi.Input[str]] = None,
                 src_ip: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Forward resources.
        :param pulumi.Input[str] dst_port: The destination port for the forwarding.
        :param pulumi.Input[bool] enabled: Specifies whether the port forwarding rule is enabled or not. This will attribute will be removed in a future release. Instead of disabling a port forwarding rule you can remove it from your configuration.
        :param pulumi.Input[str] fwd_ip: The IPv4 address to forward traffic to.
        :param pulumi.Input[str] fwd_port: The port to forward traffic to.
        :param pulumi.Input[bool] log: Specifies whether to log forwarded traffic or not. Defaults to `false`.
        :param pulumi.Input[str] name: The name of the port forwarding rule.
        :param pulumi.Input[str] port_forward_interface: The port forwarding interface. Can be `wan`, `wan2`, or `both`.
        :param pulumi.Input[str] protocol: The protocol for the port forwarding rule. Can be `tcp`, `udp`, or `tcp_udp`. Defaults to `tcp_udp`.
        :param pulumi.Input[str] site: The name of the site to associate the port forwarding rule with.
        :param pulumi.Input[str] src_ip: The source IPv4 address (or CIDR) of the port forwarding rule. For all traffic, specify `any`. Defaults to `any`.
        """
        if dst_port is not None:
            pulumi.set(__self__, "dst_port", dst_port)
        if enabled is not None:
            warnings.warn("""This will attribute will be removed in a future release. Instead of disabling a port forwarding rule you can remove it from your configuration.""", DeprecationWarning)
            pulumi.log.warn("""enabled is deprecated: This will attribute will be removed in a future release. Instead of disabling a port forwarding rule you can remove it from your configuration.""")
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if fwd_ip is not None:
            pulumi.set(__self__, "fwd_ip", fwd_ip)
        if fwd_port is not None:
            pulumi.set(__self__, "fwd_port", fwd_port)
        if log is not None:
            pulumi.set(__self__, "log", log)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if port_forward_interface is not None:
            pulumi.set(__self__, "port_forward_interface", port_forward_interface)
        if protocol is not None:
            pulumi.set(__self__, "protocol", protocol)
        if site is not None:
            pulumi.set(__self__, "site", site)
        if src_ip is not None:
            pulumi.set(__self__, "src_ip", src_ip)

    @property
    @pulumi.getter(name="dstPort")
    def dst_port(self) -> Optional[pulumi.Input[str]]:
        """
        The destination port for the forwarding.
        """
        return pulumi.get(self, "dst_port")

    @dst_port.setter
    def dst_port(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "dst_port", value)

    @property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Specifies whether the port forwarding rule is enabled or not. This will attribute will be removed in a future release. Instead of disabling a port forwarding rule you can remove it from your configuration.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "enabled", value)

    @property
    @pulumi.getter(name="fwdIp")
    def fwd_ip(self) -> Optional[pulumi.Input[str]]:
        """
        The IPv4 address to forward traffic to.
        """
        return pulumi.get(self, "fwd_ip")

    @fwd_ip.setter
    def fwd_ip(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "fwd_ip", value)

    @property
    @pulumi.getter(name="fwdPort")
    def fwd_port(self) -> Optional[pulumi.Input[str]]:
        """
        The port to forward traffic to.
        """
        return pulumi.get(self, "fwd_port")

    @fwd_port.setter
    def fwd_port(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "fwd_port", value)

    @property
    @pulumi.getter
    def log(self) -> Optional[pulumi.Input[bool]]:
        """
        Specifies whether to log forwarded traffic or not. Defaults to `false`.
        """
        return pulumi.get(self, "log")

    @log.setter
    def log(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "log", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the port forwarding rule.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="portForwardInterface")
    def port_forward_interface(self) -> Optional[pulumi.Input[str]]:
        """
        The port forwarding interface. Can be `wan`, `wan2`, or `both`.
        """
        return pulumi.get(self, "port_forward_interface")

    @port_forward_interface.setter
    def port_forward_interface(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "port_forward_interface", value)

    @property
    @pulumi.getter
    def protocol(self) -> Optional[pulumi.Input[str]]:
        """
        The protocol for the port forwarding rule. Can be `tcp`, `udp`, or `tcp_udp`. Defaults to `tcp_udp`.
        """
        return pulumi.get(self, "protocol")

    @protocol.setter
    def protocol(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "protocol", value)

    @property
    @pulumi.getter
    def site(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the site to associate the port forwarding rule with.
        """
        return pulumi.get(self, "site")

    @site.setter
    def site(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "site", value)

    @property
    @pulumi.getter(name="srcIp")
    def src_ip(self) -> Optional[pulumi.Input[str]]:
        """
        The source IPv4 address (or CIDR) of the port forwarding rule. For all traffic, specify `any`. Defaults to `any`.
        """
        return pulumi.get(self, "src_ip")

    @src_ip.setter
    def src_ip(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "src_ip", value)


class Forward(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 dst_port: Optional[pulumi.Input[str]] = None,
                 enabled: Optional[pulumi.Input[bool]] = None,
                 fwd_ip: Optional[pulumi.Input[str]] = None,
                 fwd_port: Optional[pulumi.Input[str]] = None,
                 log: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 port_forward_interface: Optional[pulumi.Input[str]] = None,
                 protocol: Optional[pulumi.Input[str]] = None,
                 site: Optional[pulumi.Input[str]] = None,
                 src_ip: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        `port.Forward` manages a port forwarding rule on the gateway.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] dst_port: The destination port for the forwarding.
        :param pulumi.Input[bool] enabled: Specifies whether the port forwarding rule is enabled or not. This will attribute will be removed in a future release. Instead of disabling a port forwarding rule you can remove it from your configuration.
        :param pulumi.Input[str] fwd_ip: The IPv4 address to forward traffic to.
        :param pulumi.Input[str] fwd_port: The port to forward traffic to.
        :param pulumi.Input[bool] log: Specifies whether to log forwarded traffic or not. Defaults to `false`.
        :param pulumi.Input[str] name: The name of the port forwarding rule.
        :param pulumi.Input[str] port_forward_interface: The port forwarding interface. Can be `wan`, `wan2`, or `both`.
        :param pulumi.Input[str] protocol: The protocol for the port forwarding rule. Can be `tcp`, `udp`, or `tcp_udp`. Defaults to `tcp_udp`.
        :param pulumi.Input[str] site: The name of the site to associate the port forwarding rule with.
        :param pulumi.Input[str] src_ip: The source IPv4 address (or CIDR) of the port forwarding rule. For all traffic, specify `any`. Defaults to `any`.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[ForwardArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        `port.Forward` manages a port forwarding rule on the gateway.

        :param str resource_name: The name of the resource.
        :param ForwardArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ForwardArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 dst_port: Optional[pulumi.Input[str]] = None,
                 enabled: Optional[pulumi.Input[bool]] = None,
                 fwd_ip: Optional[pulumi.Input[str]] = None,
                 fwd_port: Optional[pulumi.Input[str]] = None,
                 log: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 port_forward_interface: Optional[pulumi.Input[str]] = None,
                 protocol: Optional[pulumi.Input[str]] = None,
                 site: Optional[pulumi.Input[str]] = None,
                 src_ip: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ForwardArgs.__new__(ForwardArgs)

            __props__.__dict__["dst_port"] = dst_port
            if enabled is not None and not opts.urn:
                warnings.warn("""This will attribute will be removed in a future release. Instead of disabling a port forwarding rule you can remove it from your configuration.""", DeprecationWarning)
                pulumi.log.warn("""enabled is deprecated: This will attribute will be removed in a future release. Instead of disabling a port forwarding rule you can remove it from your configuration.""")
            __props__.__dict__["enabled"] = enabled
            __props__.__dict__["fwd_ip"] = fwd_ip
            __props__.__dict__["fwd_port"] = fwd_port
            __props__.__dict__["log"] = log
            __props__.__dict__["name"] = name
            __props__.__dict__["port_forward_interface"] = port_forward_interface
            __props__.__dict__["protocol"] = protocol
            __props__.__dict__["site"] = site
            __props__.__dict__["src_ip"] = src_ip
        super(Forward, __self__).__init__(
            'unifi:port/forward:Forward',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            dst_port: Optional[pulumi.Input[str]] = None,
            enabled: Optional[pulumi.Input[bool]] = None,
            fwd_ip: Optional[pulumi.Input[str]] = None,
            fwd_port: Optional[pulumi.Input[str]] = None,
            log: Optional[pulumi.Input[bool]] = None,
            name: Optional[pulumi.Input[str]] = None,
            port_forward_interface: Optional[pulumi.Input[str]] = None,
            protocol: Optional[pulumi.Input[str]] = None,
            site: Optional[pulumi.Input[str]] = None,
            src_ip: Optional[pulumi.Input[str]] = None) -> 'Forward':
        """
        Get an existing Forward resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] dst_port: The destination port for the forwarding.
        :param pulumi.Input[bool] enabled: Specifies whether the port forwarding rule is enabled or not. This will attribute will be removed in a future release. Instead of disabling a port forwarding rule you can remove it from your configuration.
        :param pulumi.Input[str] fwd_ip: The IPv4 address to forward traffic to.
        :param pulumi.Input[str] fwd_port: The port to forward traffic to.
        :param pulumi.Input[bool] log: Specifies whether to log forwarded traffic or not. Defaults to `false`.
        :param pulumi.Input[str] name: The name of the port forwarding rule.
        :param pulumi.Input[str] port_forward_interface: The port forwarding interface. Can be `wan`, `wan2`, or `both`.
        :param pulumi.Input[str] protocol: The protocol for the port forwarding rule. Can be `tcp`, `udp`, or `tcp_udp`. Defaults to `tcp_udp`.
        :param pulumi.Input[str] site: The name of the site to associate the port forwarding rule with.
        :param pulumi.Input[str] src_ip: The source IPv4 address (or CIDR) of the port forwarding rule. For all traffic, specify `any`. Defaults to `any`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ForwardState.__new__(_ForwardState)

        __props__.__dict__["dst_port"] = dst_port
        __props__.__dict__["enabled"] = enabled
        __props__.__dict__["fwd_ip"] = fwd_ip
        __props__.__dict__["fwd_port"] = fwd_port
        __props__.__dict__["log"] = log
        __props__.__dict__["name"] = name
        __props__.__dict__["port_forward_interface"] = port_forward_interface
        __props__.__dict__["protocol"] = protocol
        __props__.__dict__["site"] = site
        __props__.__dict__["src_ip"] = src_ip
        return Forward(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="dstPort")
    def dst_port(self) -> pulumi.Output[Optional[str]]:
        """
        The destination port for the forwarding.
        """
        return pulumi.get(self, "dst_port")

    @property
    @pulumi.getter
    def enabled(self) -> pulumi.Output[Optional[bool]]:
        """
        Specifies whether the port forwarding rule is enabled or not. This will attribute will be removed in a future release. Instead of disabling a port forwarding rule you can remove it from your configuration.
        """
        return pulumi.get(self, "enabled")

    @property
    @pulumi.getter(name="fwdIp")
    def fwd_ip(self) -> pulumi.Output[Optional[str]]:
        """
        The IPv4 address to forward traffic to.
        """
        return pulumi.get(self, "fwd_ip")

    @property
    @pulumi.getter(name="fwdPort")
    def fwd_port(self) -> pulumi.Output[Optional[str]]:
        """
        The port to forward traffic to.
        """
        return pulumi.get(self, "fwd_port")

    @property
    @pulumi.getter
    def log(self) -> pulumi.Output[Optional[bool]]:
        """
        Specifies whether to log forwarded traffic or not. Defaults to `false`.
        """
        return pulumi.get(self, "log")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The name of the port forwarding rule.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="portForwardInterface")
    def port_forward_interface(self) -> pulumi.Output[Optional[str]]:
        """
        The port forwarding interface. Can be `wan`, `wan2`, or `both`.
        """
        return pulumi.get(self, "port_forward_interface")

    @property
    @pulumi.getter
    def protocol(self) -> pulumi.Output[Optional[str]]:
        """
        The protocol for the port forwarding rule. Can be `tcp`, `udp`, or `tcp_udp`. Defaults to `tcp_udp`.
        """
        return pulumi.get(self, "protocol")

    @property
    @pulumi.getter
    def site(self) -> pulumi.Output[str]:
        """
        The name of the site to associate the port forwarding rule with.
        """
        return pulumi.get(self, "site")

    @property
    @pulumi.getter(name="srcIp")
    def src_ip(self) -> pulumi.Output[Optional[str]]:
        """
        The source IPv4 address (or CIDR) of the port forwarding rule. For all traffic, specify `any`. Defaults to `any`.
        """
        return pulumi.get(self, "src_ip")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['GroupArgs', 'Group']

@pulumi.input_type
class GroupArgs:
    def __init__(__self__, *,
                 name: Optional[pulumi.Input[str]] = None,
                 qos_rate_max_down: Optional[pulumi.Input[int]] = None,
                 qos_rate_max_up: Optional[pulumi.Input[int]] = None,
                 site: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a Group resource.
        :param pulumi.Input[str] name: The name of the user group.
        :param pulumi.Input[int] qos_rate_max_down: The QOS maximum download rate. Defaults to `-1`.
        :param pulumi.Input[int] qos_rate_max_up: The QOS maximum upload rate. Defaults to `-1`.
        :param pulumi.Input[str] site: The name of the site to associate the user group with.
        """
        if name is not None:
            pulumi.set(__self__, "name", name)
        if qos_rate_max_down is not None:
            pulumi.set(__self__, "qos_rate_max_down", qos_rate_max_down)
        if qos_rate_max_up is not None:
            pulumi.set(__self__, "qos_rate_max_up", qos_rate_max_up)
        if site is not None:
            pulumi.set(__self__, "site", site)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the user group.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="qosRateMaxDown")
    def qos_rate_max_down(self) -> Optional[pulumi.Input[int]]:
        """
        The QOS maximum download rate. Defaults to `-1`.
        """
        return pulumi.get(self, "qos_rate_max_down")

    @qos_rate_max_down.setter
    def qos_rate_max_down(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "qos_rate_max_down", value)

    @property
    @pulumi.getter(name="qosRateMaxUp")
    def qos_rate_max_up(self) -> Optional[pulumi.Input[int]]:
        """
        The QOS maximum upload rate. Defaults to `-1`.
        """
        return pulumi.get(self, "qos_rate_max_up")

    @qos_rate_max_up.setter
    def qos_rate_max_up(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "qos_rate_max_up", value)

    @property
    @pulumi.getter
    def site(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the site to associate the user group with.
        """
        return pulumi.get(self, "site")

    @site.setter
    def site(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "site", value)


@pulumi.input_type
class _GroupState:
    def __init__(__self__, *,
                 name: Optional[pulumi.Input[str]] = None,
                 qos_rate_max_down: Optional[pulumi.Input[int]] = None,
                 qos_rate_max_up: Optional[pulumi.Input[int]] = None,
                 site: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Group resources.
        :param pulumi.Input[str] name: The name of the user group.
        :param pulumi.Input[int] qos_rate_max_down: The QOS maximum download rate. Defaults to `-1`.
        :param pulumi.Input[int] qos_rate_max_up: The QOS maximum upload rate. Defaults to `-1`.
        :param pulumi.Input[str] site: The name of the site to associate the user group with.
        """
        if name is not None:
            pulumi.set(__self__, "name", name)
        if qos_rate_max_down is not None:
            pulumi.set(__self__, "qos_rate_max_down", qos_rate_max_down)
        if qos_rate_max_up is not None:
            pulumi.set(__self__, "qos_rate_max_up", qos_rate_max_up)
        if site is not None:
            pulumi.set(__self__, "site", site)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the user group.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="qosRateMaxDown")
    def qos_rate_max_down(self) -> Optional[pulumi.Input[int]]:
        """
        The QOS maximum download rate. Defaults to `-1`.
        """
        return pulumi.get(self, "qos_rate_max_down")

    @qos_rate_max_down.setter
    def qos_rate_max_down(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "qos_rate_max_down", value)

    @property
    @pulumi.getter(name="qosRateMaxUp")
    def qos_rate_max_up(self) -> Optional[pulumi.Input[int]]:
        """
        The QOS maximum upload rate. Defaults to `-1`.
        """
        return pulumi.get(self, "qos_rate_max_up")

    @qos_rate_max_up.setter
    def qos_rate_max_up(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "qos_rate_max_up", value)

    @property
    @pulumi.getter
    def site(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the site to associate the user group with.
        """
        return pulumi.get(self, "site")

    @site.setter
    def site(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "site", value)


class Group(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 qos_rate_max_down: Optional[pulumi.Input[int]] = None,
                 qos_rate_max_up: Optional[pulumi.Input[int]] = None,
                 site: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        `iam.Group` manages a user group (called "client group" in the UI), which can be used to limit bandwidth for groups of users.

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_unifi as unifi

        wifi = unifi.iam.Group("wifi",
            qos_rate_max_down=2000,
            qos_rate_max_up=10)
        # 10kbps
        ```

        ## Import

        import using the ID

        ```sh
         $ pulumi import unifi:iam/group:Group wifi 5fe6261995fe130013456a36
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] name: The name of the user group.
        :param pulumi.Input[int] qos_rate_max_down: The QOS maximum download rate. Defaults to `-1`.
        :param pulumi.Input[int] qos_rate_max_up: The QOS maximum upload rate. Defaults to `-1`.
        :param pulumi.Input[str] site: The name of the site to associate the user group with.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[GroupArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        `iam.Group` manages a user group (called "client group" in the UI), which can be used to limit bandwidth for groups of users.

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_unifi as unifi

        wifi = unifi.iam.Group("wifi",
            qos_rate_max_down=2000,
            qos_rate_max_up=10)
        # 10kbps
        ```

        ## Import

        import using the ID

        ```sh
         $ pulumi import unifi:iam/group:Group wifi 5fe6261995fe130013456a36
        ```

        :param str resource_name: The name of the resource.
        :param GroupArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(GroupArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 qos_rate_max_down: Optional[pulumi.Input[int]] = None,
                 qos_rate_max_up: Optional[pulumi.Input[int]] = None,
                 site: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = GroupArgs.__new__(GroupArgs)

            __props__.__dict__["name"] = name
            __props__.__dict__["qos_rate_max_down"] = qos_rate_max_down
            __props__.__dict__["qos_rate_max_up"] = qos_rate_max_up
            __props__.__dict__["site"] = site
        super(Group, __self__).__init__(
            'unifi:iam/group:Group',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            name: Optional[pulumi.Input[str]] = None,
            qos_rate_max_down: Optional[pulumi.Input[int]] = None,
            qos_rate_max_up: Optional[pulumi.Input[int]] = None,
            site: Optional[pulumi.Input[str]] = None) -> 'Group':
        """
        Get an existing Group resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] name: The name of the user group.
        :param pulumi.Input[int] qos_rate_max_down: The QOS maximum download rate. Defaults to `-1`.
        :param pulumi.Input[int] qos_rate_max_up: The QOS maximum upload rate. Defaults to `-1`.
        :param pulumi.Input[str] site: The name of the site to associate the user group with.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _GroupState.__new__(_GroupState)

        __props__.__dict__["name"] = name
        __props__.__dict__["qos_rate_max_down"] = qos_rate_max_down
        __props__.__dict__["qos_rate_max_up"] = qos_rate_max_up
        __props__.__dict__["site"] = site
        return Group(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The name of the user group.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="qosRateMaxDown")
    def qos_rate_max_down(self) -> pulumi.Output[Optional[int]]:
        """
        The QOS maximum download rate. Defaults to `-1`.
        """
        return pulumi.get(self, "qos_rate_max_down")

    @property
    @pulumi.getter(name="qosRateMaxUp")
    def qos_rate_max_up(self) -> pulumi.Output[Optional[int]]:
        """
        The QOS maximum upload rate. Defaults to `-1`.
        """
        return pulumi.get(self, "qos_rate_max_up")

    @property
    @pulumi.getter
    def site(self) -> pulumi.Output[str]:
        """
        The name of the site to associate the user group with.
        """
        return pulumi.get(self, "site")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'GetProfileResult',
    'AwaitableGetProfileResult',
    'get_profile',
    'get_profile_output',
]

@pulumi.output_type
class GetProfileResult:
    """
    A collection of values returned by getProfile.
    """
    def __init__(__self__, id=None, name=None, site=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if site and not isinstance(site, str):
            raise TypeError("Expected argument 'site' to be a str")
        pulumi.set(__self__, "site", site)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of this port profile.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> Optional[str]:
        """
        The name of the port profile to look up. Defaults to `All`.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def site(self) -> str:
        """
        The name of the site the port profile is associated with.
        """
        return pulumi.get(self, "site")


class AwaitableGetProfileResult(GetProfileResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetProfileResult(
            id=self.id,
            name=self.name,
            site=self.site)


def get_profile(name: Optional[str] = None,
                site: Optional[str] = None,
                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetProfileResult:
    """
    `port.Profile` data source can be used to retrieve the ID for a port profile by name.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_unifi as unifi

    all = unifi.port.get_profile()
    ```


    :param str name: The name of the port profile to look up. Defaults to `All`.
    :param str site: The name of the site the port profile is associated with.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['site'] = site
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('unifi:port/getProfile:getProfile', __args__, opts=opts, typ=GetProfileResult).value

    return AwaitableGetProfileResult(
        id=__ret__.id,
        name=__ret__.name,
        site=__ret__.site)


@_utilities.lift_output_func(get_profile)
def get_profile_output(name: Optional[pulumi.Input[Optional[str]]] = None,
                       site: Optional[pulumi.Input[Optional[str]]] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetProfileResult]:
    """
    `port.Profile` data source can be used to retrieve the ID for a port profile by name.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_unifi as unifi

    all = unifi.port.get_profile()
    ```


    :param str name: The name of the port profile to look up. Defaults to `All`.
    :param str site: The name of the site the port profile is associated with.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['MgmtArgs', 'Mgmt']

@pulumi.input_type
class MgmtArgs:
    def __init__(__self__, *,
                 auto_upgrade: Optional[pulumi.Input[bool]] = None,
                 site: Optional[pulumi.Input[str]] = None,
                 ssh_enabled: Optional[pulumi.Input[bool]] = None,
                 ssh_keys: Optional[pulumi.Input[Sequence[pulumi.Input['MgmtSshKeyArgs']]]] = None):
        """
        The set of arguments for constructing a Mgmt resource.
        :param pulumi.Input[bool] auto_upgrade: Automatically upgrade device firmware.
        :param pulumi.Input[str] site: The name of the site to associate the settings with.
        :param pulumi.Input[bool] ssh_enabled: Enable SSH authentication.
        :param pulumi.Input[Sequence[pulumi.Input['MgmtSshKeyArgs']]] ssh_keys: SSH key.
        """
        if auto_upgrade is not None:
            pulumi.set(__self__, "auto_upgrade", auto_upgrade)
        if site is not None:
            pulumi.set(__self__, "site", site)
        if ssh_enabled is not None:
            pulumi.set(__self__, "ssh_enabled", ssh_enabled)
        if ssh_keys is not None:
            pulumi.set(__self__, "ssh_keys", ssh_keys)

    @property
    @pulumi.getter(name="autoUpgrade")
    def auto_upgrade(self) -> Optional[pulumi.Input[bool]]:
        """
        Automatically upgrade device firmware.
        """
        return pulumi.get(self, "auto_upgrade")

    @auto_upgrade.setter
    def auto_upgrade(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "auto_upgrade", value)

    @property
    @pulumi.getter
    def site(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the site to associate the settings with.
        """
        return pulumi.get(self, "site")

    @site.setter
    def site(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "site", value)

    @property
    @pulumi.getter(name="sshEnabled")
    def ssh_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable SSH authentication.
        """
        return pulumi.get(self, "ssh_enabled")

    @ssh_enabled.setter
    def ssh_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "ssh_enabled", value)

    @property
    @pulumi.getter(name="sshKeys")
    def ssh_keys(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['MgmtSshKeyArgs']]]]:
        """
        SSH key.
        """
        return pulumi.get(self, "ssh_keys")

    @ssh_keys.setter
    def ssh_keys(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['MgmtSshKeyArgs']]]]):
        pulumi.set(self, "ssh_keys", value)


@pulumi.input_type
class _MgmtState:
    def __init__(__self__, *,
                 auto_upgrade: Optional[pulumi.Input[bool]] = None,
                 site: Optional[pulumi.Input[str]] = None,
                 ssh_enabled: Optional[pulumi.Input[bool]] = None,
                 ssh_keys: Optional[pulumi.Input[Sequence[pulumi.Input['MgmtSshKeyArgs']]]] = None):
        """
        Input properties used for looking up and filtering Mgmt resources.
        :param pulumi.Input[bool] auto_upgrade: Automatically upgrade device firmware.
        :param pulumi.Input[str] site: The name of the site to associate the settings with.
        :param pulumi.Input[bool] ssh_enabled: Enable SSH authentication.
        :param pulumi.Input[Sequence[pulumi.Input['MgmtSshKeyArgs']]] ssh_keys: SSH key.
        """
        if auto_upgrade is not None:
            pulumi.set(__self__, "auto_upgrade", auto_upgrade)
        if site is not None:
            pulumi.set(__self__, "site", site)
        if ssh_enabled is not None:
            pulumi.set(__self__, "ssh_enabled", ssh_enabled)
        if ssh_keys is not None:
            pulumi.set(__self__, "ssh_keys", ssh_keys)

    @property
    @pulumi.getter(name="autoUpgrade")
    def auto_upgrade(self) -> Optional[pulumi.Input[bool]]:
        """
        Automatically upgrade device firmware.
        """
        return pulumi.get(self, "auto_upgrade")

    @auto_upgrade.setter
    def auto_upgrade(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "auto_upgrade", value)

    @property
    @pulumi.getter
    def site(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the site to associate the settings with.
        """
        return pulumi.get(self, "site")

    @site.setter
    def site(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "site", value)

    @property
    @pulumi.getter(name="sshEnabled")
    def ssh_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable SSH authentication.
        """
        return pulumi.get(self, "ssh_enabled")

    @ssh_enabled.setter
    def ssh_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "ssh_enabled", value)

    @property
    @pulumi.getter(name="sshKeys")
    def ssh_keys(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['MgmtSshKeyArgs']]]]:
        """
        SSH key.
        """
        return pulumi.get(self, "ssh_keys")

    @ssh_keys.setter
    def ssh_keys(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['MgmtSshKeyArgs']]]]):
        pulumi.set(self, "ssh_keys", value)


class Mgmt(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auto_upgrade: Optional[pulumi.Input[bool]] = None,
                 site: Optional[pulumi.Input[str]] = None,
                 ssh_enabled: Optional[pulumi.Input[bool]] = None,
                 ssh_keys: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['MgmtSshKeyArgs']]]]] = None,
                 __props__=None):
        """
        `setting.Mgmt` manages settings for a unifi site.

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_unifi as unifi

        example_site = unifi.Site("exampleSite", description="example")
        example_mgmt = unifi.setting.Mgmt("exampleMgmt",
            site=example_site.name,
            auto_upgrade=True)
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] auto_upgrade: Automatically upgrade device firmware.
        :param pulumi.Input[str] site: The name of the site to associate the settings with.
        :param pulumi.Input[bool] ssh_enabled: Enable SSH authentication.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['MgmtSshKeyArgs']]]] ssh_keys: SSH key.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[MgmtArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        `setting.Mgmt` manages settings for a unifi site.

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_unifi as unifi

        example_site = unifi.Site("exampleSite", description="example")
        example_mgmt = unifi.setting.Mgmt("exampleMgmt",
            site=example_site.name,
            auto_upgrade=True)
        ```

        :param str resource_name: The name of the resource.
        :param MgmtArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(MgmtArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auto_upgrade: Optional[pulumi.Input[bool]] = None,
                 site: Optional[pulumi.Input[str]] = None,
                 ssh_enabled: Optional[pulumi.Input[bool]] = None,
                 ssh_keys: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['MgmtSshKeyArgs']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = MgmtArgs.__new__(MgmtArgs)

            __props__.__dict__["auto_upgrade"] = auto_upgrade
            __props__.__dict__["site"] = site
            __props__.__dict__["ssh_enabled"] = ssh_enabled
            __props__.__dict__["ssh_keys"] = ssh_keys
        super(Mgmt, __self__).__init__(
            'unifi:setting/mgmt:Mgmt',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            auto_upgrade: Optional[pulumi.Input[bool]] = None,
            site: Optional[pulumi.Input[str]] = None,
            ssh_enabled: Optional[pulumi.Input[bool]] = None,
            ssh_keys: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['MgmtSshKeyArgs']]]]] = None) -> 'Mgmt':
        """
        Get an existing Mgmt resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] auto_upgrade: Automatically upgrade device firmware.
        :param pulumi.Input[str] site: The name of the site to associate the settings with.
        :param pulumi.Input[bool] ssh_enabled: Enable SSH authentication.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['MgmtSshKeyArgs']]]] ssh_keys: SSH key.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _MgmtState.__new__(_MgmtState)

        __props__.__dict__["auto_upgrade"] = auto_upgrade
        __props__.__dict__["site"] = site
        __props__.__dict__["ssh_enabled"] = ssh_enabled
        __props__.__dict__["ssh_keys"] = ssh_keys
        return Mgmt(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="autoUpgrade")
    def auto_upgrade(self) -> pulumi.Output[Optional[bool]]:
        """
        Automatically upgrade device firmware.
        """
        return pulumi.get(self, "auto_upgrade")

    @property
    @pulumi.getter
    def site(self) -> pulumi.Output[str]:
        """
        The name of the site to associate the settings with.
        """
        return pulumi.get(self, "site")

    @property
    @pulumi.getter(name="sshEnabled")
    def ssh_enabled(self) -> pulumi.Output[Optional[bool]]:
        """
        Enable SSH authentication.
        """
        return pulumi.get(self, "ssh_enabled")

    @property
    @pulumi.getter(name="sshKeys")
    def ssh_keys(self) -> pulumi.Output[Optional[Sequence['outputs.MgmtSshKey']]]:
        """
        SSH key.
        """
        return pulumi.get(self, "ssh_keys")

